@@ -492,7 +492,7 @@ def _start(client, bot):
 			else:
 				nowloop=line
 				try:
-					r=line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0].replace(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1],line[len(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]+";"+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]+";"):])
+					r=line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0].replace(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1],line[len(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]+bot._separator+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]+bot._separator):])
 					line=line.replace("$replaceText"+bot._style[0]+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(r))
 				except:
 					line=line.replace("$replaceText"+bot._style[0]+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none") 
@@ -571,6 +571,7 @@ def _start(client, bot):
 		return line
 	
 	async def use(message, name, trigger, type):
+		import time
 		vars={}
 		restart=True
 		while restart:
@@ -624,7 +625,7 @@ def _start(client, bot):
 										timerep="0"
 									else:
 										timerep=str(bot._cooldown[name]["user"][str(author.id)]-int(time.time() - startTime))
-								except:
+								except Exception as e:
 									timerep="0"
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
 								if bot._cooldown[name]["user"][str(author.id)]>int(time.time() - startTime):
@@ -977,9 +978,11 @@ def _start(client, bot):
 								line=line[len("$addReactions"+bot._style[0]):]
 								line=line[:-1]
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
+								mes=await ctx.fetch_message(int(line.split(bot._separator)[0]))
+								line=line[len(line.split(bot._separator)[0]+bot._separator):]
 								for react in line.split(bot._separator):
 									try:
-										await msg.add_reaction(react)
+										await mes.add_reaction(react)
 									except:
 										pass
 						elif line.startswith("$typing"):
